pub async fn git_branches(repo: &Path) -> Result<BranchInfo, GitError>Expand description
Return the list of local branches and identify the current one.
pub async fn git_branches(repo: &Path) -> Result<BranchInfo, GitError>Return the list of local branches and identify the current one.