pub struct GitDir {
pub git_dir: PathBuf,
pub is_regular: bool,
}Expand description
Information about the git directory layout for a given repo path.
Fields
git_dir: PathBufThe absolute path to the actual git directory (.git for
regular repos, the repo path itself for bare repos).
is_regular: booltrue if this is a regular (non-bare) repository.