pub fn git_cors_header_pairs() -> Vec<(String, String)>Expand description
GIT_CORS_HEADERS as owned pairs, ready to extend a header Vec.
pub fn git_cors_header_pairs() -> Vec<(String, String)>GIT_CORS_HEADERS as owned pairs, ready to extend a header Vec.